@@ -7,7 +7,7 @@ sys.path.insert(0, os.path.abspath(".."))
 import snntorch
 
 # fmt: off
-__version__ = '0.4.1'
+__version__ = '0.4.2'
 # fmt: on
 
 
@@ -71,7 +71,8 @@ html_theme = "sphinx_rtd_theme"
 
 # The name of an image file (relative to this directory) to place at the top
 # of the sidebar.
-html_logo = "img/snntorch_alpha_full.png"
+# html_logo = "_static/img/snntorch_alpha_full.png"  # RTD is adding an additional _static here
+html_logo = "_static/img/snntorch_alpha_full.png"
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
